@@ -21,6 +21,9 @@
 #' profiles), and "varying" (free covariances across profiles).
 #' @param package Character. Which package to use; 'mclust' or
 #' 'MplusAutomation' (requires Mplus to be installed). Default: 'mclust'.
+#' @param select_vars Character. Optional vector of variable names in \code{df},
+#' to be used for model estimation. Defaults to \code{NULL}, which means all
+#' variables in \code{df} are used.
 #' @param ... Additional arguments are passed to the estimating function; i.e.,
 #' \code{\link[mclust]{Mclust}}, or \code{\link[MplusAutomation]{mplusModeler}}.
 #' @return A list of class 'tidyLPA'.
@@ -30,8 +33,8 @@
 #' \item Equal variances and covariances fixed to 0
 #' \item Varying variances and covariances fixed to 0
 #' \item Equal variances and equal covariances
-#' \item Varying variances and equal covariances
-#' \item Equal variances and varying covariances
+#' \item Varying variances and equal covariances (not able to be fit w/ mclust)
+#' \item Equal variances and varying covariances (not able to be fit w/ mclust)
 #' \item Varying variances and varying covariances
 #' }
 #'
@@ -58,7 +61,7 @@
 #'   estimate_profiles(n_profiles = 1:4, models = 1:3)
 #'
 #' # Example 3:
-#' iris_subset %>%
+#' iris_sample %>%
 #'   subset(select = c("Sepal.Length", "Sepal.Width",
 #'     "Petal.Length")) %>%
 #'   estimate_profiles(n_profiles = 1:4, variances = c("equal", "varying"),
@@ -72,6 +75,7 @@ estimate_profiles <- function(df,
                               variances = "equal",
                               covariances = "zero",
                               package = "mclust",
+                              select_vars = NULL,
                               ...) {
     UseMethod("estimate_profiles", df)
 }
@@ -118,6 +122,7 @@ estimate_profiles.default <- function(df,
                                       variances = "equal",
                                       covariances = "zero",
                                       package = "mclust",
+                                      select_vars = NULL,
                                       ...) {
     # Check deprecated arguments ----------------------------------------------
 
@@ -132,6 +137,19 @@ estimate_profiles.default <- function(df,
         "scale_raw_data" = "Before running estimate_profiles, run the function 'scale' on your data (see ?scale). Also see ?poms (percentage-of-maximum scoring) for a way to put your variables on an easily comparable scale."
     ))
 
+    # Check if there is an argument 'select_vars'' ----------------------------
+    if(!is.null(select_vars)){
+        if(!all(select_vars %in% names(df))){
+            stop("The following variables are not in df: ", paste(select_vars[!select_vars %in% names(df)], collapse = ", "))
+        }
+    } else {
+        select_vars <- names(df)
+    }
+    # Backup df
+    df_full <- df
+    df <- df[, select_vars, drop = FALSE]
+
+    # Deprecated variable selection -------------------------------------------
     check_dots <- match.call(expand.dots = FALSE)$`...`
     if(any(names(df) %in% unlist(check_dots))){
         warning("It looks like you are trying to extract some variables from df. This functionality is deprecated. Instead, estimate_profiles() always uses all variables in df. Select your variables prior to analysis, using either:\n  The dplyr function select(df, Your, Selected, Variable, Names), or\n  The base R function df[, c('Your', 'Selected', 'Variable', 'Names')]")
@@ -183,8 +201,8 @@ estimate_profiles.default <- function(df,
     }
 
     out <- switch(package,
-           "mplusautomation" = estimate_profiles_mplus2(df, n_profiles, model_numbers, ...),
-           "mclust" = estimate_profiles_mclust(df, n_profiles, model_numbers, ...))
+           "mplusautomation" = estimate_profiles_mplus2(df_full, n_profiles, model_numbers, select_vars, ...),
+           "mclust" = estimate_profiles_mclust(df_full, n_profiles, model_numbers, select_vars, ...))
 
     # Check warnings here
     warnings <- sapply(out, function(x){!is.null(x[["warnings"]])})
@@ -241,7 +259,7 @@ get_estimates.tidyProfile <- function(x, ...) {
 #' @param x An object generated by tidyLPA.
 #' @param ... further arguments to be passed to or from other methods. They are
 #' ignored in this function.
-#' @return A tibble.
+#' @return A tibble. Learn more at https://data-edu.github.io/tidyLPA/articles/Introduction_to_tidyLPA.html#getting-fit-statistics
 #' @author Caspar J. van Lissa
 #' @examples
 #' \dontrun{
@@ -277,16 +295,25 @@ get_fit.tidyProfile <- function(x, ...) {
 #' @param x An object generated by tidyLPA.
 #' @param ... further arguments to be passed to or from other methods. They are
 #' ignored in this function.
-#' @return A tibble.
+#' @return If one model is fit, the data is returned in wide format as a tibble.
+#' If more than one model is fit, the data is returned in long form. See the
+#' examples.
 #' @author Caspar J. van Lissa
 #' @examples
 #' \dontrun{
 #' if(interactive()){
+#'  library(dplyr)
+#'  # the data is returned in wide form
 #'  results <- iris %>%
 #'    select(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width) %>%
 #'    estimate_profiles(3)
 #'  get_data(results)
-#'  get_data(results[[1]])
+#'
+#'  # note that if more than one model is fit, the data is returned in long form
+#'  results1 <- iris %>%
+#'    select(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width) %>%
+#'    estimate_profiles(c(3, 4))
+#'  get_data(results1)
 #'  }
 #' }
 #' @export
@@ -298,36 +325,55 @@ get_data <- function(x, ...) {
 #' numbers of classes and models, of class 'tidyLPA'.
 #' @export
 get_data.tidyLPA <- function(x, ...) {
-    out <- lapply(x, function(x) {
-        dt <- data.frame(x[["dff"]])
-        prob_names <- grep("^CPROB", names(dt), value = TRUE)
-        if (length(prob_names) > 1) {
-            reshape(
-                dt,
-                varying = c("Probability" = prob_names),
-                direction = "long",
-                v.names = "Probability",
-                timevar = "Class_prob",
-                sep = ""
-            )
-        } else {
-            cbind(
-                dt[, 1:(ncol(dt) - 2)],
-                Class = dt$Class,
-                Class_prob = dt$Class,
-                Probability = dt$CPROB1,
-                id = 1:nrow(dt)
-            )
-        }
-    })
-    as_tibble(do.call(rbind, out))
+    cl <- match.call()
+    if(length(x) == 1){
+        cl$x <- x[[1]]
+        cl[[1]] <- as.name("get_data")
+        return(eval.parent(cl))
+    }
+    as_tibble(do.call(get_long_data, as.list(cl[-1])))
 }
 
 #' @describeIn get_data Get data for a single latent profile analysis object,
 #' of class 'tidyProfile'.
 #' @export
 get_data.tidyProfile <- function(x, ...) {
-    x[["dff"]]
+    if(!is.null(x[["dff"]])){
+        x[["dff"]]
+    } else {
+        stop("This tidyProfile has no data attached.")
+    }
+}
+
+
+# Internal ----------------------------------------------------------------
+
+get_long_data <- function(x, ...) {
+    out <- lapply(x, function(x) {
+        if(!is.null(x[["dff"]])){
+            dt <- data.frame(x[["dff"]])
+            prob_names <- grep("^CPROB", names(dt), value = TRUE)
+            if (length(prob_names) > 1) {
+                reshape(
+                    dt,
+                    varying = c("Probability" = prob_names),
+                    direction = "long",
+                    v.names = "Probability",
+                    timevar = "Class_prob",
+                    sep = ""
+                )
+            } else {
+                cbind(
+                    dt[, 1:(ncol(dt) - 2)],
+                    Class = dt$Class,
+                    Class_prob = dt$Class,
+                    Probability = dt$CPROB1,
+                    id = 1:nrow(dt)
+                )
+            }
+        }
+    })
+    do.call(rbind, out)
 }
 
 #' @title Print tidyLPA
@@ -362,7 +408,7 @@ print.tidyLPA <-
                        "n_min",
                        "n_max",
                        "BLRT_p"),
-             digits = 3,
+             digits = 2,
              na.print = "",
              ...) {
         fits <- get_fit(x)
@@ -404,7 +450,7 @@ print.tidyLPA <-
 #' @export
 print.tidyProfile <-
     function(x,
-             digits = 3,
+             digits = 2,
              na.print = "",
              ...) {
         dat <- get_fit(x)
