@@ -7,13 +7,13 @@ comment = "#>"
 ## ---- eval = FALSE-------------------------------------------------------
 #  install.packages("tidyLPA")
 
-## ---- gh-installation, eval = FALSE--------------------------------------
+## ----gh-installation, eval = FALSE---------------------------------------
 #  install.packages("devtools")
 #  devtools::install_github("data-edu/tidyLPA")
 
 ## ---- message = F--------------------------------------------------------
 library(tidyLPA)
-library(dplyr)
+library(tidyverse)
 
 ## ------------------------------------------------------------------------
 pisaUSA15[1:100, ] %>%
@@ -39,17 +39,10 @@ pisaUSA15[1:100, ] %>%
 pisaUSA15[1:100, ] %>%
     select(broad_interest, enjoyment, self_efficacy) %>%
     single_imputation() %>%
-    scale() %>%
-    estimate_profiles(n_profiles = 2:4) %>% 
-    plot_profiles()
-
-## ---- eval = FALSE-------------------------------------------------------
-#  pisaUSA15[1:100, ] %>%
-#      single_imputation() %>%
-#      estimate_profiles(1:3,
-#                        variances = c("equal", "varying"),
-#                        covariances = c("zero", "varying")) %>%
-#      compare_solutions(statistics = c("AIC", "BIC"))
+    estimate_profiles(1:3, 
+                      variances = c("equal", "varying"),
+                      covariances = c("zero", "varying")) %>%
+    compare_solutions(statistics = c("AIC", "BIC"))
 
 ## ---- eval = TRUE--------------------------------------------------------
 pisaUSA15[1:100, ] %>%
@@ -81,3 +74,14 @@ pisaUSA15[1:100, ] %>%
 ## ---- eval = TRUE--------------------------------------------------------
 get_data(m3)
 
+## ------------------------------------------------------------------------
+m4 <- pisaUSA15[1:100, ] %>%
+    select(broad_interest, enjoyment, self_efficacy) %>%
+    single_imputation() %>% 
+    estimate_profiles(c(3, 4))
+
+get_data(m4)
+
+## ------------------------------------------------------------------------
+get_fit(m4)
+
